@@ -32,8 +32,10 @@
 #include "icons.h"
 #include "util.h"
 #include "v7snac13.h"
+#include "personal_info.h"
 
 #include <gtk/gtk.h>
+#include <string.h>
 
 void auth_sendbutton_clicked (GtkWidget *w, gpointer d);
 void auth_cancelbutton_clicked (GtkWidget *w, gpointer d);
