@@ -7,9 +7,8 @@
 #ifndef __CHANGENICK_H__
 #define __CHANGENICK_H__
 
-#include "common.h"
+#include <gtk/gtkwidget.h>
 
-void change_nick( GtkWidget *widget, gpointer data );
 void change_nick_window( GtkWidget *widget, gpointer data );
 
 #endif /* __CHANGENICK_H__ */
