@@ -109,6 +109,7 @@ typedef struct
 #define STATUS_DND_MAC         0x02
 #define STATUS_AIM_ONLINE      0x1000
 #define STATUS_AIM_AWAY        0x3000
+#define STATUS_CUSTOM          0x5000
 
 #define USER_ADDED_MESS        0x000c
 #define AUTH_REQ_MESS          0x0006
@@ -183,7 +184,7 @@ typedef enum
 	MESSAGE_CHAT_REQ,    /* Request to start a chat */
 	MESSAGE_AUTH_REQ,    /* Request for authorization */
 	MESSAGE_USER_ADD,    /* User has added you to his/her list */
-	MESSAGE_USER_AUTHD,  /* User has authorized you to add him/her */
+	MESSAGE_USER_AUTHD,  /* User has authorized/denied you to add him/her */
 	MESSAGE_CONT_LIST    /* Received contact list */
 } MESSAGE_TYPES;
 
