@@ -18,17 +18,12 @@
 
 #include "common.h"
 #include "dirbrowser.h"
-
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#include <dirent.h>
-#include <unistd.h>
+#include "gnomeicu.h"
 
 #include <string.h>
-
+#include <dirent.h>
+#include <sys/stat.h>
 #include <gtk/gtk.h>
-#include <stdio.h>
 
 static char *folder[] =
 {
@@ -108,7 +103,7 @@ static gboolean check_for_subdir(gchar * path)
 	struct stat statbuf;
 	gchar *npath;
 
-	if ((dir = opendir(path)) != NULL)
+	if (path && (dir = opendir(path)) != NULL)
 	{
 		while ((dirent = readdir(dir)) != NULL)
 		{
@@ -160,7 +155,7 @@ static void expand_cb(GtkWidget * widget, GtkCTreeNode * parent_node)
 				path = g_strconcat(parent_dirnode->path, dirent->d_name, NULL);
 				if (stat(path, &statbuf) != -1 && S_ISDIR(statbuf.st_mode) && dirent->d_name[0] != '.')
 				{
-					dirnode = g_malloc0(sizeof (DirNode));
+					dirnode = g_new0(DirNode, 1);
 					dirnode->path = g_strconcat(path, "/", NULL);
 					text = dirent->d_name;
 					if (check_for_subdir(dirnode->path))
@@ -194,9 +189,9 @@ static void select_row_cb(GtkWidget * widget, gint row, gint column, GdkEventBut
 		{
 			node = gtk_ctree_node_nth(GTK_CTREE(widget), row);
 			dirnode = gtk_ctree_node_get_row_data(GTK_CTREE(widget), node);
-			handler = (void (*)(gchar *, gpointer)) gtk_object_get_data(GTK_OBJECT(widget), "handler");
+			handler = (void (*)(gchar *, gpointer)) g_object_get_data(G_OBJECT(widget), "handler");
 			if (handler)
-				handler(dirnode->path, gtk_object_get_data(GTK_OBJECT(widget), "user_data"));
+				handler(dirnode->path, g_object_get_data(G_OBJECT(widget), "user_data"));
 		}
 	}
 
@@ -210,16 +205,16 @@ static void ok_clicked(GtkWidget * widget, GtkWidget * tree)
 	GtkWidget *window;
 	void (*handler) (gchar *, gpointer);
 
-	window = gtk_object_get_user_data(GTK_OBJECT(widget));
+	window = g_object_get_data(G_OBJECT(widget), "window");
 	gtk_widget_hide(window);
 	list_node = GTK_CLIST(tree)->selection;
 	while (list_node)
 	{
 		node = list_node->data;
 		dirnode = gtk_ctree_node_get_row_data(GTK_CTREE(tree), node);
-		handler = (void (*)(gchar *, gpointer)) gtk_object_get_data(GTK_OBJECT(tree), "handler");
+		handler = (void (*)(gchar *, gpointer)) g_object_get_data(G_OBJECT(tree), "handler");
 		if (handler)
-			handler(dirnode->path, gtk_object_get_data(GTK_OBJECT(tree), "user_data"));
+			handler(dirnode->path, g_object_get_data(G_OBJECT(tree), "user_data"));
 		list_node = g_list_next(list_node);
 	}
 	gtk_widget_destroy(window);
@@ -234,7 +229,9 @@ GtkWidget *create_dir_browser(gchar * title, void (*handler) (gchar *, gpointer)
 	GtkCTreeNode *root_node, *node;
 	DirNode *dirnode;
 
-	window = gtk_window_new(GTK_WINDOW_DIALOG);
+	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_transient_for(GTK_WINDOW(window), 
+				     GTK_WINDOW(MainData->window));
 	gtk_window_set_title(GTK_WINDOW(window), title);
 	gtk_container_border_width(GTK_CONTAINER(window), 10);
 
@@ -258,14 +255,14 @@ GtkWidget *create_dir_browser(gchar * title, void (*handler) (gchar *, gpointer)
 	gtk_clist_set_column_auto_resize(GTK_CLIST(tree), 0, TRUE);
 	gtk_clist_set_selection_mode(GTK_CLIST(tree), GTK_SELECTION_SINGLE);
 	gtk_ctree_set_line_style(GTK_CTREE(tree), GTK_CTREE_LINES_DOTTED);
-	gtk_signal_connect(GTK_OBJECT(tree), "tree_expand", GTK_SIGNAL_FUNC(expand_cb), NULL);
-	gtk_signal_connect(GTK_OBJECT(tree), "select_row", GTK_SIGNAL_FUNC(select_row_cb), NULL);
+	g_signal_connect(G_OBJECT(tree), "tree_expand", G_CALLBACK(expand_cb), NULL);
+	g_signal_connect(G_OBJECT(tree), "select_row", G_CALLBACK(select_row_cb), NULL);
 	gtk_container_add(GTK_CONTAINER(scroll_win), tree);
-	gtk_object_set_data(GTK_OBJECT(tree), "handler", (gpointer) handler);
-  gtk_object_set_data(GTK_OBJECT(tree), "user_data", (gpointer) user_data);
+	g_object_set_data(G_OBJECT(tree), "handler", handler);
+	g_object_set_data(G_OBJECT(tree), "user_data", user_data);
 
 	root_node = gtk_ctree_insert_node(GTK_CTREE(tree), NULL, NULL, &root_text, 4, folder_pixmap, folder_mask, ofolder_pixmap, ofolder_mask, FALSE, FALSE);
-	dirnode = g_malloc0(sizeof (DirNode));
+	dirnode = g_new0(DirNode, 1);
 	dirnode->path = g_strdup("/");
 	gtk_ctree_node_set_row_data_full(GTK_CTREE(tree), root_node, dirnode, destroy_cb);
 	node = gtk_ctree_insert_node(GTK_CTREE(tree), root_node, NULL, &node_text, 4, NULL, NULL, NULL, NULL, TRUE, TRUE);
@@ -281,17 +278,17 @@ GtkWidget *create_dir_browser(gchar * title, void (*handler) (gchar *, gpointer)
 	gtk_button_box_set_spacing(GTK_BUTTON_BOX(bbox), 5);
 
 	ok = gtk_button_new_with_label(_("Ok"));
-	gtk_object_set_user_data(GTK_OBJECT(ok), window);
+	g_object_set_data(G_OBJECT(ok), "window", window);
 	GTK_WIDGET_SET_FLAGS(ok, GTK_CAN_DEFAULT);
 	gtk_window_set_default(GTK_WINDOW(window), ok);
 	gtk_box_pack_start(GTK_BOX(bbox), ok, TRUE, TRUE, 0);
-	gtk_signal_connect(GTK_OBJECT(ok), "clicked", GTK_SIGNAL_FUNC(ok_clicked), tree);
+	g_signal_connect(G_OBJECT(ok), "clicked", G_CALLBACK(ok_clicked), tree);
 	gtk_widget_show(ok);
 
 	cancel = gtk_button_new_with_label(_("Cancel"));
 	GTK_WIDGET_SET_FLAGS(cancel, GTK_CAN_DEFAULT);
 	gtk_box_pack_start(GTK_BOX(bbox), cancel, TRUE, TRUE, 0);
-	gtk_signal_connect_object(GTK_OBJECT(cancel), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
+	g_signal_connect_swapped(G_OBJECT(cancel), "clicked", G_CALLBACK(gtk_widget_destroy), window);
 	gtk_widget_show(cancel);
 
 	gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
@@ -303,169 +300,3 @@ GtkWidget *create_dir_browser(gchar * title, void (*handler) (gchar *, gpointer)
 	return window;
 }
 
-static int int_compare_func(const void *a, const void *b)
-{
-	if ((gint) a < (gint) b)
-		return -1;
-	if ((gint) a > (gint) b)
-		return 1;
-	else
-		return 0;
-}
-
-static gboolean filebrowser_is_dir(GtkFileSelection * filesel)
-{
-	gchar *text;
-	struct stat buf;
-	
-	text = g_strdup(gtk_file_selection_get_filename(filesel));
-	g_strstrip(text);
-	while ((text[strlen(text) - 1] == '/') &&
-	       (strlen(text) > 1) && (text[strlen(text) - 2] == '/'))
-	{
-		text[strlen(text) - 1] = '\0';
-	}
-
-	if (stat(text, &buf) == 0)
-	{
-		if (S_ISDIR(buf.st_mode))
-		{		/* Selected directory */
-			gtk_file_selection_set_filename(filesel, text);
-			g_free(text);
-			return TRUE;
-		}
-	}
-	g_free(text);
-	return FALSE;
-}
-
-static void filebrowser_add_files(GtkFileSelection * filesel)
-{
-	GList *sel_list = NULL, *node;
-	gchar *text, *text2, *text3;
-	void (*handler)(gchar *, gpointer data);
-
-	handler = gtk_object_get_data(GTK_OBJECT(filesel), "handler");
-
-	text3 = g_strdup(gtk_file_selection_get_filename(filesel));
-	if(!text3)
-		return;
-	
-	text = strrchr(text3, '/');
-	if (text)
-		*(text + 1) = '\0';
-
-	node = GTK_CLIST(filesel->file_list)->selection;
-	while(node)
-	{
-		sel_list = g_list_prepend(sel_list, node->data);
-		node = g_list_next(node);
-	}
-	sel_list = g_list_sort(sel_list, int_compare_func);
-
-	node = sel_list;
-	
-	if (node)
-	{
-		while (node)
-		{
-			gtk_clist_get_text(GTK_CLIST(filesel->file_list), GPOINTER_TO_INT(node->data), 0, &text);
-			text2 = g_strconcat(text3, text, NULL);
-
-			handler(text2, gtk_object_get_data(GTK_OBJECT(filesel), "user_data"));
-			g_free(text2);
-			node = g_list_next(node);
-		}
-	}
-	else
-	{
-		/*
-		 * No files selected, but the user may have
-		 * typed a filename.
-		 */		
-		text = gtk_file_selection_get_filename(filesel);
-		if (text[strlen(text) - 1] != '/')
-			handler(text, gtk_object_get_data(GTK_OBJECT(filesel), "user_data"));
-	}
-	g_list_free(sel_list);
-	g_free(text3);
-	gtk_file_selection_set_filename(GTK_FILE_SELECTION(filesel), "");
-}
-
-static void filebrowser_ok(GtkWidget * w, GtkWidget * filesel)
-{
-	if(!filebrowser_is_dir(GTK_FILE_SELECTION(filesel)))
-	{
-		gtk_widget_hide(filesel);
-		filebrowser_add_files(GTK_FILE_SELECTION(filesel));
-		gtk_widget_destroy(filesel);
-	}
-}
-
-static void filebrowser_add_selected_files(GtkWidget * w, GtkWidget * filesel)
-{
-	filebrowser_add_files(GTK_FILE_SELECTION(filesel));
-}
-
-static void filebrowser_add_all_files(GtkWidget * w, GtkWidget * filesel)
-{
-	if(GTK_CLIST(GTK_FILE_SELECTION(filesel)->file_list)->row_list)
-	{
-		gtk_clist_freeze(GTK_CLIST(GTK_FILE_SELECTION(filesel)->file_list));
-		gtk_clist_select_all(GTK_CLIST(GTK_FILE_SELECTION(filesel)->file_list));
-		filebrowser_add_files(GTK_FILE_SELECTION(filesel));
-		/*
-		 * We want gtk_clist_undo_selection() but it is buggy in GTK+ 1.2.6
-		 */
-		/*  gtk_clist_undo_selection(GTK_CLIST(GTK_FILE_SELECTION(filesel)->file_list)); */
-		gtk_clist_unselect_all(GTK_CLIST(GTK_FILE_SELECTION(filesel)->file_list));
-		gtk_clist_thaw(GTK_CLIST(GTK_FILE_SELECTION(filesel)->file_list));
-	}
-}
-
-GtkWidget * create_filebrowser( void (*callback)(gchar *, gpointer), gpointer data )
-{
-	GtkWidget *filebrowser, *bbox, *add_selected, *add_all, *label;
-
-	filebrowser = gtk_file_selection_new(_("Send file(s)"));
-		
-	gtk_object_set_data(GTK_OBJECT(filebrowser), "handler", (gpointer)callback);
-  gtk_object_set_data(GTK_OBJECT(filebrowser), "user_data", data);
-
-	gtk_clist_set_selection_mode(GTK_CLIST(GTK_FILE_SELECTION(filebrowser)->file_list),
-				     GTK_SELECTION_EXTENDED);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filebrowser)->ok_button),
-			   "clicked", GTK_SIGNAL_FUNC(filebrowser_ok), filebrowser);
-	gtk_signal_connect_object(GTK_OBJECT(GTK_FILE_SELECTION(filebrowser)->cancel_button),
-				  "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				  GTK_OBJECT(filebrowser));
-
-	bbox = gtk_hbutton_box_new();
-	gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX(bbox), 0);
-	gtk_box_pack_end(GTK_BOX(GTK_FILE_SELECTION(filebrowser)->action_area),
-			 bbox, TRUE, TRUE, 0);
-	add_selected  = gtk_button_new_with_label(_("Add selected files"));
-	gtk_box_pack_start(GTK_BOX(bbox), add_selected, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(add_selected), "clicked",
-			   GTK_SIGNAL_FUNC(filebrowser_add_selected_files), filebrowser);
-	add_all = gtk_button_new_with_label(_("Add all files in directory"));
-	gtk_box_pack_start(GTK_BOX(bbox), add_all, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(add_all), "clicked",
-			   GTK_SIGNAL_FUNC(filebrowser_add_all_files), filebrowser);
-	gtk_widget_show_all(bbox);
-
-	/*
-	 * This is ugly.
-	 * Change the Cancel buttons caption to Close.
-	 */
-	label = gtk_label_new(_("Close"));
-	gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
-	gtk_container_remove(GTK_CONTAINER(GTK_FILE_SELECTION(filebrowser)->cancel_button),
-			     gtk_container_children(GTK_CONTAINER(GTK_FILE_SELECTION(filebrowser)->cancel_button))->data);
-	gtk_container_add(GTK_CONTAINER(GTK_FILE_SELECTION(filebrowser)->cancel_button), label);
-	gtk_widget_show(label);
-
-	gtk_widget_show(filebrowser);
-	return filebrowser;
-}
