@@ -22,9 +22,12 @@
 #include "util.h"
 #include "v7login.h"
 #include "v7send.h"
+#include "v7snac13.h"
 #include "groups.h"
 #include "group_popup.h"
 #include "auto_respond.h"
+#include "auth.h"
+#include "newsignup.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
@@ -55,7 +58,7 @@ static void del_file( GtkWidget *widget, gpointer data );
 /* static void open_dir( GtkWidget *widget, gpointer data ); */
 
 static void icq_user_added_you_msgbox(GSList *contact);
-static void icq_user_authorized_you_msgbox(GSList *contact);
+static void icq_user_authorized_you_msgbox(STORED_MESSAGE_PTR message_text, GSList *contact);
 static void icq_filetransfer_window(STORED_MESSAGE_PTR message_text,
 				    GSList* contact);
 static void icq_authorization_request_window(STORED_MESSAGE_PTR message_text,
@@ -173,19 +176,38 @@ static void icq_user_added_you_msgbox(GSList *contact)
 }
 
 
-static void icq_user_authorized_you_msgbox(GSList *contact)
+static void icq_user_authorized_you_msgbox(STORED_MESSAGE_PTR message_text, GSList *contact)
 {
 	GtkWidget *dialog;
 
 	g_assert(contact != NULL);
-	dialog = gtk_message_dialog_new (GTK_WINDOW (MainData->window),
-	                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-	                                 GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-	                                 _("You are authorized to add %s to your list"),
-	                                 kontakt->nick);
-	gtk_widget_show (dialog);
+	if (message_text->data) {
+	  dialog = gtk_message_dialog_new (GTK_WINDOW (MainData->window),
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+					   _("You are authorized to add %s to your list"),
+					   kontakt->nick);
+	} else {
+	  dialog = gtk_message_dialog_new (GTK_WINDOW (MainData->window),
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+					   _("You are NOT authorized to add %s to your list"),
+					   kontakt->nick);
+	}
+
+	if (message_text->message) {
+	  g_print(message_text->message);
+	  gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+						   "%s", 
+						   message_text->message);
+	}
+
+
 	g_signal_connect (G_OBJECT (dialog), "response",
 	                  G_CALLBACK (gtk_widget_destroy), NULL);
+
+	gtk_widget_show (dialog);
+
 }
 
 
@@ -478,7 +500,7 @@ void icq_msgbox( STORED_MESSAGE_PTR message_text, UIN_T uin )
 
 	case MESSAGE_USER_AUTHD:
 		/*** Sender has authorized you to add him to your list ***/
-		icq_user_authorized_you_msgbox(contact);
+		icq_user_authorized_you_msgbox(message_text, contact);
 		break;
 
 	case MESSAGE_CHAT_REQ:
@@ -704,9 +726,9 @@ void remove_contact(GSList *contact, gboolean rem_history)
 
 	gnomeicu_tree_user_remove (kontakt);
 
-	Contacts = g_slist_remove (Contacts, contact->data);
-
         g_free (contact->data);
+
+	Contacts = g_slist_remove (Contacts, contact->data);	
 }
 
 void icq_set_status( GtkWidget *widget, gpointer data )
