@@ -197,7 +197,7 @@ preferences_get_list (const gchar *key, GConfValueType ltype)
 {
   GSList *ret_list;
 
-  g_return_if_fail (key);
+  g_return_val_if_fail (key, NULL);
 
   if (!prefs_init)
     preferences_init ();
@@ -214,7 +214,7 @@ preferences_get_pair (const gchar *key, GConfValueType car_type,
 {
   gboolean retval;
 
-  g_return_if_fail (key || car_retloc || cdr_retloc);
+  g_return_val_if_fail (key || car_retloc || cdr_retloc, FALSE);
 
   if (!prefs_init)
     preferences_init ();
@@ -231,7 +231,7 @@ preferences_get_string (const gchar *gconf_key)
 {
   gchar *str;
 
-  g_return_if_fail (gconf_key);
+  g_return_val_if_fail (gconf_key, NULL);
 
   if (!prefs_init)
     preferences_init ();
@@ -247,7 +247,7 @@ preferences_get_string (const gchar *gconf_key)
 gint
 preferences_get_int (const gchar *gconf_key)
 {
-  g_return_if_fail (gconf_key);
+  g_return_val_if_fail (gconf_key, NULL);
 
   if (!prefs_init)
     preferences_init ();
@@ -258,7 +258,7 @@ preferences_get_int (const gchar *gconf_key)
 gboolean
 preferences_get_bool (const gchar *gconf_key)
 {
-  g_return_if_fail (gconf_key);
+  g_return_val_if_fail (gconf_key, FALSE);
 
   if (!prefs_init)
     preferences_init ();
@@ -272,7 +272,7 @@ preferences_get_color (const gchar *gconf_key)
   gchar *color_string;
   GdkColor *my_color;
 
-  g_return_if_fail (gconf_key);
+  g_return_val_if_fail (gconf_key, NULL);
 
   if (!prefs_init)
     preferences_init ();
