@@ -419,7 +419,7 @@ static struct _program_event_values program_events[] = {
   { PREFS_GNOMEICU_PROG_EVENT_FILE_REQ, N_("File request") },
   { PREFS_GNOMEICU_PROG_EVENT_USER_ONLINE, N_("User online") },
   { PREFS_GNOMEICU_PROG_EVENT_USER_OFFLINE, N_("User offline") },
-  { PREFS_GNOMEICU_PROG_EVENT_AUTH_USER, N_("Authorized by user") },
+  { PREFS_GNOMEICU_PROG_EVENT_AUTH_USER, N_("Authorized/Rejected by user") },
   { PREFS_GNOMEICU_PROG_EVENT_AUTH_REQ, N_("Authorization request") },
   { PREFS_GNOMEICU_PROG_EVENT_ADDED_TO_USER, N_("Added to user's list") },
   { PREFS_GNOMEICU_PROG_EVENT_CONTACT_LIST, N_("Contact list received") },
