@@ -33,6 +33,7 @@
 #include "groups.h"
 #include "group_popup.h"
 #include "util.h"
+#include "msg.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtknotebook.h>
@@ -358,7 +359,7 @@ set_group (GtkTreeStore *store, gint gid, gint special)
     g = (GroupInfo *)ginfo->data;
 
     if (g->name)
-      group_name = g_strndup (g->name, strlen(g->name));
+      group_name = g_markup_escape_text (g->name, strlen(g->name));
     else
       group_name = g_strdup(_("Unknown Group Name"));
     str = g_strdup_printf ("<b>%s</b> (%d/%d)",
@@ -384,14 +385,18 @@ set_group (GtkTreeStore *store, gint gid, gint special)
 static void
 set_contact (GtkTreeStore *store, GtkTreeIter *parent, Contact_Member *contact)
 {
-  gchar *str;
+  gchar *str=NULL, *nick=NULL;
   GtkTreeIter child;
 
   g_assert (store != NULL && parent != NULL && contact != NULL);
 
+  nick = g_markup_escape_text(contact->nick, strlen(contact->nick));
+
   str = g_strdup_printf("<span foreground=\"%s\">%s</span>",
                         get_foreground_for_status(contact->status),
-                        contact->nick);
+                        nick);
+
+  g_free(nick);
 
   gtk_tree_store_prepend (store, &child, parent);
   gtk_tree_store_set (store, &child,
@@ -413,7 +418,7 @@ update_group (GtkTreeStore *store, GtkTreeIter *iter)
 {
   GroupInfo *group;
   gint special;
-  gchar *str;
+  gchar *str, *str2;
 
   g_assert (store != NULL && iter != NULL);
 
@@ -422,8 +427,10 @@ update_group (GtkTreeStore *store, GtkTreeIter *iter)
                       SPECIAL_COLUMN, &special,
                       -1);
   if (special == GROUP_NORMAL) {
+    str2 = g_markup_escape_text(group->name, strlen(group->name));
     str = g_strdup_printf ("<b>%s</b> (%d/%d)",
-                           group->name, group->online_user, group->total_user);
+                           str2, group->online_user, group->total_user);
+    g_free(str2);
   } else if (special == GROUP_WAIT_FOR_AUTH) {
     return;
   } else if (special == GROUP_NOT_IN_LIST) {
@@ -439,15 +446,18 @@ static void
 update_contact (GtkTreeStore *store, GtkTreeIter *iter)
 {
   Contact_Member *contact;
-  gchar *str;
+  gchar *str=NULL, *nick=NULL;
 
   g_assert (store != NULL && iter != NULL);
 
   gtk_tree_model_get (GTK_TREE_MODEL (store), iter,
                       CONTACT_COLUMN, &contact, -1);
+
+  nick = g_markup_escape_text(contact->nick, strlen(contact->nick));
+
   str = g_strdup_printf("<span foreground=\"%s\">%s</span>",
                         get_foreground_for_status(contact->status),
-                        contact->nick);
+                        nick);
   gtk_tree_store_set (store, iter,
                       ICON_COLUMN, get_pixbuf_for_status (contact->status),
                       TEXT_COLUMN, str,
@@ -457,6 +467,7 @@ update_contact (GtkTreeStore *store, GtkTreeIter *iter)
     gtk_tree_store_set (store, iter,
 			ICON2_COLUMN, icon_birthday_pixbuf,
 			-1);
+  g_free(nick);
   g_free (str);
 }
 
@@ -999,18 +1010,8 @@ static void search_nick_in_treeview(GtkTreeView *widget, GdkEventKey *ev,
 			if (!g_ascii_strncasecmp(nick_collated, search_collated, search_nick->len)) {
 				/* this nickname matches the search
 				   => we select the contact */
-#if GTK_CHECK_VERSION(2,2,0)
 				tree_path = gtk_tree_model_get_path(tree_model, &child);
 				gtk_tree_view_expand_to_path(widget, tree_path);
-#else
-				/* gtk_tree_view_expand_to_path is a GTK+ 2.2
-				 * API addition, so we have to do the same thing
-				 * manually for GTK+ 2.0 */
-				tree_path = gtk_tree_model_get_path(tree_model, &iter);
-				gtk_tree_view_expand_row(widget, tree_path, TRUE);
-				gtk_tree_path_free(tree_path);
-				tree_path = gtk_tree_model_get_path(tree_model, &child);
-#endif
 				gtk_tree_view_set_cursor(widget, tree_path, NULL, FALSE);
 				gtk_tree_path_free(tree_path);
 				g_free(nick_collated);
